@@ -12,7 +12,7 @@ class IncludeSimple(MetaDataObject):
 
     @classmethod
     def decode(cls, src_dir, file_name, dest_dir, dest_path, version):
-        raise Exception('Так быть не должно, это класс обслуживает вложенные объекты')
+        raise Exception('Так быть не должно, этот класс обслуживает вложенные объекты')
 
     @classmethod
     def decode_local_include(cls, parent, header_data, src_dir, dest_dir, dest_path, version):
